@@ -64,16 +64,18 @@ gint
 twoline2tle (gchar *line1, gchar *line2, gchar *line3,
              gboolean checksum, tle_t *tle)
 {
+    /* FIXME */
+    (void) checksum; /* avoid unused parameter compiler warning */
 
     /* check function parameters */
     if G_UNLIKELY((line1 == NULL) || (line2 == NULL) || (line3 == NULL)) {
-        sat_log_log (SAT_LOG_LEVEL_BUG,
-                     _("%s: NULL input data!"), __FUNCTION__);
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: NULL input data!"), __func__);
         return TLE_CONV_ERROR;
     }
     if G_UNLIKELY(tle == NULL) {
-        sat_log_log (SAT_LOG_LEVEL_BUG,
-                     _("%s: NULL output storage!"), __FUNCTION__);
+        sat_log_log (SAT_LOG_LEVEL_ERROR,
+                     _("%s: NULL output storage!"), __func__);
         return TLE_CONV_ERROR;
     }
 
@@ -100,6 +102,11 @@ twoline2tle (gchar *line1, gchar *line2, gchar *line3,
 gint
 tle2twoline (tle_t *tle, gchar *line1, gchar *line2, gchar *line3)
 {
+    (void) tle; /* avoid unused parameter compiler warning */
+    (void) line1; /* avoid unused parameter compiler warning */
+    (void) line2; /* avoid unused parameter compiler warning */
+    (void) line3; /* avoid unused parameter compiler warning */
+    
     return TLE_CONV_SUCCESS;
 }
 
